/** A tracer that implements the Tracer interface with noop methods. */
const noopTracer = {
  log: () => void 0,
  requestSent: () => void 0,
  requestReceived: () => void 0,
  notificationSent: () => void 0,
  notificationReceived: () => void 0,
  responseSent: () => void 0,
  responseAborted: () => void 0,
  responseReceived: () => void 0,
  unknownResponseReceived: () => void 0
};
/** A tracer that implements the Tracer interface with console API calls, intended for a web browser. */
class BrowserConsoleTracer {
  name;
  constructor(name) {
    this.name = name;
  }
  prefix(level, label, title) {
    let color;
    let backgroundColor;
    if (level === 'info') {
      color = '#000';
      backgroundColor = '#eee';
    } else {
      color = 'white';
      backgroundColor = 'red';
    }
    return ['%c%s%c %s%c%s%c', `font-weight:bold;background-color:#d8f7ff;color:black`, this.name, '', label, `background-color:${backgroundColor};color:${color};font-weight:bold`, title, ''];
  }
  log(message, details) {
    if (details) {
      console.groupCollapsed(...this.prefix('info', 'log', ''), message);
      console.log(details);
      console.groupEnd();
    } else {
      console.log(...this.prefix('info', 'log', ''), message);
    }
  }
  requestSent(message) {
    console.log(...this.prefix('info', `◀◀ sent request #${message.id}: `, message.method), message.params);
  }
  requestReceived(message) {
    console.log(...this.prefix('info', `▶▶ recv request #${message.id}: `, message.method), message.params);
  }
  notificationSent(message) {
    console.log(...this.prefix('info', `◀◀ sent notif: `, message.method), message.params);
  }
  notificationReceived(message) {
    console.log(...this.prefix('info', `▶▶ recv notif: `, message.method), message.params);
  }
  responseSent(message, request, startTime) {
    const prefix = this.prefix(message.error ? 'error' : 'info', `◀▶ sent response #${message.id}: `, typeof request === 'string' ? request : request.method);
    console.groupCollapsed(...prefix);
    console.log('Response:', message);
    console.log('Request:', request);
    console.log('Duration: %d msec', Date.now() - startTime);
    console.groupEnd();
  }
  responseAborted(_message, request, _abortMessage) {
    console.log(...this.prefix('info', '× abort: ', request.method));
  }
  responseReceived(message, request, startTime) {
    const prefix = this.prefix(message.error ? 'error' : 'info', `◀▶ recv response #${message.id}: `, typeof request === 'string' ? request : request.method);
    if (typeof request === 'string') {
      console.log(...prefix, message.error || message.result);
    } else {
      console.groupCollapsed(...prefix);
      console.log('Response:', message);
      console.log('Request:', request);
      console.log('Duration: %d msec', Date.now() - startTime);
      console.groupEnd();
    }
  }
  unknownResponseReceived(message) {
    console.log(...this.prefix('error', 'UNKNOWN', ''), message);
  }
}export{BrowserConsoleTracer,noopTracer};//# sourceMappingURL=trace.js.map
